
# Slot: decreases activity of


holds between two molecular entities where the action or effect of one decreases the activity of the other within a system of interest

URI: [biolink:decreases_activity_of](https://w3id.org/biolink/vocab/decreases_activity_of)


## Domain and Range

[MolecularEntity](MolecularEntity.md) &#8594;  <sub>0..\*</sub> [MolecularEntity](MolecularEntity.md)

## Parents

 *  is_a: [affects activity of](affects_activity_of.md)

## Children


## Used by


## Other properties

|  |  |  |
| --- | --- | --- |
| **In Subsets:** | | translator_minimal |
| **Exact Mappings:** | | CTD:decreases_activity_of |
| **Narrow Mappings:** | | GAMMA:allosteric_antagonist |
|  | | GAMMA:partial_antagonist |
|  | | GAMMA:antagonist |
|  | | GAMMA:weak_inhibitor |
|  | | GAMMA:inhibitor |
|  | | GAMMA:channel_blocker |
|  | | GAMMA:gating_inhibitor |
|  | | GAMMA:blocker |
|  | | GAMMA:inverse_agonist |
|  | | GAMMA:inactivator |
|  | | GAMMA:downregulator |
|  | | GAMMA:negative_modulator |
|  | | GAMMA:negative_allosteric_modulator |
|  | | GAMMA:inhibitory_allosteric_modulator |
|  | | GAMMA:aggregation_inhibitor |
|  | | GAMMA:conversion_inhibitor |
|  | | GAMMA:suppressor |
|  | | CHEMBL.MECHANISM:antagonist |
|  | | CHEMBL.MECHANISM:allosteric_antagonist |
|  | | CHEMBL.MECHANISM:inverse_agonist |
|  | | DGIdb:antagonist |
|  | | DGIdb:blocker |
|  | | DGIdb:channel_blocker |
|  | | DGIdb:gating_inhibitor |
|  | | DGIdb:inhibitor |
|  | | DGIdb:negative_modulator |
|  | | DGIdb:inhibitory_allosteric_modulator |
|  | | DGIdb:inverse_agonist |
| **Related Mappings:** | | GAMMA:ic50 |
|  | | GAMMA:ki |
|  | | DGIdb:vaccine |

